gridref_to_xy: Convert Grid Ref to XY

Description Usage Arguments Value

View source: R/gridref_to_xy.R

Description

This function converts ordinance survey grid references to eastings northing

Usage

1

Arguments

x

A vector of ordinance survey grid references such as 'TA 123 231'

Value

A tibble of eastings and northings coordinates and their resolution


MatthewJWhittle/osgridref documentation built on July 13, 2020, 2:31 a.m.