square_lookup: Square coordinates of the British National Grid

Description Usage Format

Description

A dataset containing the letter codes, xmin and ymin coordinates of squares on the british naitonal grid

Usage

1

Format

A data frame with 104 rows and 3 variables:

x

xmin of grid square

y

ymin of grid square

square_letters

the two letter code for each grid square


MatthewJWhittle/osgridref documentation built on July 13, 2020, 2:31 a.m.