Description Usage Arguments Value
View source: R/gridref_to_xy.R
This function converts ordinance survey grid references to eastings northing
1 |
x |
A vector of ordinance survey grid references such as 'TA 123 231' |
A tibble of eastings and northings coordinates and their resolution
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.