A dataset containing the letter codes, xmin and ymin coordinates of squares on the british naitonal grid
1 |
A data frame with 104 rows and 3 variables:
xmin of grid square
ymin of grid square
the two letter code for each grid square
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.